.. SciKit-Learn Laboratory documentation master file, created by
   sphinx-quickstart on Tue Jul 16 09:06:32 2013.

SciKit-Learn Laboratory (SKLL)
==============================

.. image:: skll.png
   :alt: SKLL logo
   :align: right

.. container:: clear

    .. image:: spacer.png

SKLL (pronounced "skull") provides a number of utilities to make it simpler to
run common scikit-learn experiments with pre-generated features.

There are two primary means of using SKLL: :doc:`the run_experiment script <run_experiment>`
and :doc:`the Python API <api>`.


Documentation
=============

.. toctree::
   :maxdepth: 3

   getting_started
   tutorial
   run_experiment
   utilities
   api


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

